==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Components.java <==
package com.example.model;

/**
 * Model for Components
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "Components", description = "Model for Components")
@javax.xml.bind.annotation.XmlRootElement(name = "Components")
public class Components implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String address = null;
	private java.lang.String dob = null;
	private java.lang.String firstName = null;
	private java.lang.String fraud = null;
	private java.lang.String fullName = null;
	private java.lang.String id = null;
	private java.lang.String name = null;
	private java.lang.String surName = null;
	
	/**
	 */
	public Components address(java.lang.String address) {
		setAddress(address);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("address")
	@javax.validation.constraints.NotNull
	public java.lang.String getAddress() {
		return this.address;
	}
	public void setAddress(java.lang.String address) {
		this.address = address;
	}
	
	/**
	 */
	public Components dob(java.lang.String dob) {
		setDob(dob);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("dob")
	public java.lang.String getDob() {
		return this.dob;
	}
	public void setDob(java.lang.String dob) {
		this.dob = dob;
	}
	
	/**
	 */
	public Components firstName(java.lang.String firstName) {
		setFirstName(firstName);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("firstName")
	public java.lang.String getFirstName() {
		return this.firstName;
	}
	public void setFirstName(java.lang.String firstName) {
		this.firstName = firstName;
	}
	
	/**
	 */
	public Components fraud(java.lang.String fraud) {
		setFraud(fraud);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("fraud")
	public java.lang.String getFraud() {
		return this.fraud;
	}
	public void setFraud(java.lang.String fraud) {
		this.fraud = fraud;
	}
	
	/**
	 */
	public Components fullName(java.lang.String fullName) {
		setFullName(fullName);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("full_name")
	public java.lang.String getFullName() {
		return this.fullName;
	}
	public void setFullName(java.lang.String fullName) {
		this.fullName = fullName;
	}
	
	/**
	 */
	public Components id(java.lang.String id) {
		setId(id);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("id")
	public java.lang.String getId() {
		return this.id;
	}
	public void setId(java.lang.String id) {
		this.id = id;
	}
	
	/**
	 */
	public Components name(java.lang.String name) {
		setName(name);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("name")
	public java.lang.String getName() {
		return this.name;
	}
	public void setName(java.lang.String name) {
		this.name = name;
	}
	
	/**
	 */
	public Components surName(java.lang.String surName) {
		setSurName(surName);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("surName")
	public java.lang.String getSurName() {
		return this.surName;
	}
	public void setSurName(java.lang.String surName) {
		this.surName = surName;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Components components = (Components) o;
		return java.util.Objects.equals(this.address, components.address)
				&& java.util.Objects.equals(this.dob, components.dob)
				&& java.util.Objects.equals(this.firstName, components.firstName)
				&& java.util.Objects.equals(this.fraud, components.fraud)
				&& java.util.Objects.equals(this.fullName, components.fullName)
				&& java.util.Objects.equals(this.id, components.id)
				&& java.util.Objects.equals(this.name, components.name)
				&& java.util.Objects.equals(this.surName, components.surName);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.address, this.dob, this.firstName, this.fraud, this.fullName, this.id, this.name, this.surName);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Components {\n");
		
		sb.append("    address: ").append(toIndentedString(this.address)).append("\n");
		sb.append("    dob: ").append(toIndentedString(this.dob)).append("\n");
		sb.append("    firstName: ").append(toIndentedString(this.firstName)).append("\n");
		sb.append("    fraud: ").append(toIndentedString(this.fraud)).append("\n");
		sb.append("    fullName: ").append(toIndentedString(this.fullName)).append("\n");
		sb.append("    id: ").append(toIndentedString(this.id)).append("\n");
		sb.append("    name: ").append(toIndentedString(this.name)).append("\n");
		sb.append("    surName: ").append(toIndentedString(this.surName)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Components.java <==
package com.example.model;

/**
 * Model for Components
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "Components", description = "Model for Components")
@javax.xml.bind.annotation.XmlRootElement(name = "Components")
public class Components implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String address = null;
	private java.lang.String dob = null;
	private java.lang.String firstName = null;
	private java.lang.String fraud = null;
	private java.lang.String fullName = null;
	private java.lang.String id = null;
	private java.lang.String name = null;
	private java.lang.String surName = null;
	
	/**
	 */
	public Components address(java.lang.String address) {
		setAddress(address);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "address")
	@com.fasterxml.jackson.annotation.JsonProperty("address")
	@javax.validation.constraints.NotNull
	public java.lang.String getAddress() {
		return this.address;
	}
	public void setAddress(java.lang.String address) {
		this.address = address;
	}
	
	/**
	 */
	public Components dob(java.lang.String dob) {
		setDob(dob);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "dob")
	@com.fasterxml.jackson.annotation.JsonProperty("dob")
	public java.lang.String getDob() {
		return this.dob;
	}
	public void setDob(java.lang.String dob) {
		this.dob = dob;
	}
	
	/**
	 */
	public Components firstName(java.lang.String firstName) {
		setFirstName(firstName);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "firstName")
	@com.fasterxml.jackson.annotation.JsonProperty("firstName")
	public java.lang.String getFirstName() {
		return this.firstName;
	}
	public void setFirstName(java.lang.String firstName) {
		this.firstName = firstName;
	}
	
	/**
	 */
	public Components fraud(java.lang.String fraud) {
		setFraud(fraud);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "fraud")
	@com.fasterxml.jackson.annotation.JsonProperty("fraud")
	public java.lang.String getFraud() {
		return this.fraud;
	}
	public void setFraud(java.lang.String fraud) {
		this.fraud = fraud;
	}
	
	/**
	 */
	public Components fullName(java.lang.String fullName) {
		setFullName(fullName);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "full_name")
	@com.fasterxml.jackson.annotation.JsonProperty("full_name")
	public java.lang.String getFullName() {
		return this.fullName;
	}
	public void setFullName(java.lang.String fullName) {
		this.fullName = fullName;
	}
	
	/**
	 */
	public Components id(java.lang.String id) {
		setId(id);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "id")
	@com.fasterxml.jackson.annotation.JsonProperty("id")
	public java.lang.String getId() {
		return this.id;
	}
	public void setId(java.lang.String id) {
		this.id = id;
	}
	
	/**
	 */
	public Components name(java.lang.String name) {
		setName(name);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "name")
	@com.fasterxml.jackson.annotation.JsonProperty("name")
	public java.lang.String getName() {
		return this.name;
	}
	public void setName(java.lang.String name) {
		this.name = name;
	}
	
	/**
	 */
	public Components surName(java.lang.String surName) {
		setSurName(surName);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "surName")
	@com.fasterxml.jackson.annotation.JsonProperty("surName")
	public java.lang.String getSurName() {
		return this.surName;
	}
	public void setSurName(java.lang.String surName) {
		this.surName = surName;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Components components = (Components) o;
		return java.util.Objects.equals(this.address, components.address)
				&& java.util.Objects.equals(this.dob, components.dob)
				&& java.util.Objects.equals(this.firstName, components.firstName)
				&& java.util.Objects.equals(this.fraud, components.fraud)
				&& java.util.Objects.equals(this.fullName, components.fullName)
				&& java.util.Objects.equals(this.id, components.id)
				&& java.util.Objects.equals(this.name, components.name)
				&& java.util.Objects.equals(this.surName, components.surName);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.address, this.dob, this.firstName, this.fraud, this.fullName, this.id, this.name, this.surName);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Components {\n");
		
		sb.append("    address: ").append(toIndentedString(this.address)).append("\n");
		sb.append("    dob: ").append(toIndentedString(this.dob)).append("\n");
		sb.append("    firstName: ").append(toIndentedString(this.firstName)).append("\n");
		sb.append("    fraud: ").append(toIndentedString(this.fraud)).append("\n");
		sb.append("    fullName: ").append(toIndentedString(this.fullName)).append("\n");
		sb.append("    id: ").append(toIndentedString(this.id)).append("\n");
		sb.append("    name: ").append(toIndentedString(this.name)).append("\n");
		sb.append("    surName: ").append(toIndentedString(this.surName)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
